@@ -21,7 +21,7 @@ dist2gc <- function(p1, p2, p3, r=6378137) {
 	tc <- bearing(p1, p2) * toRad
 	tcp <- bearing(p1, p3) * toRad
     dp <- distCosine(p1, p3, r=1)
-	xtr <- asin(sin(tcp-tc) * sin(dp)) * r
+	xtr <- abs(asin(sin(tcp-tc) * sin(dp)) * r)
 	as.vector(xtr)
 }
 
